@@ -187,6 +187,14 @@ def squared_circle(xpad,ypad, diameter=1.0):
     
     return Loop(result)
 
+def rectangle(x0,x1,y0,y1):
+    return Loop([
+        (x0,y0),
+        (x1,y0),
+        (x1,y1),
+        (x0,y1)
+        ])
+
 def rounded_rectangle(x0,x1,y0,y1, diameter):    
     radius = min(diameter,x1-x0,y1-y0)*0.5 
     result = [ ]
